
bloomCode = [[
	extern float a;
	extern float b;
	extern float c;
	extern float z;
	
	vec4 effect(vec4 color, Image texture, vec2 tc, vec2 sc)
	{
		vec4 txclr = Texel(texture, tc);
	   vec4 sum = vec4(0);
	   vec2 texcoord = vec2(gl_TexCoord[0]);
	   int j;
	   

	   for(int i= -10 ;i < 1; i++)
	   {
			for (j = -3; j < 3; j++)
			{
				sum += Texel(texture, tc + vec2(j, i)*z) * 0.25;
			}
	   }
		   if (txclr.r < 0.3)
		{
		   color = sum*sum*a + txclr;
		}
		else
		{
			if (txclr.r < 0.5)
			{
				color = sum*sum*b + txclr;
			}
			else
			{
				color = sum*sum*c + txclr;
			}
		}
		return color;
	}
]]

rayCode = [[
	float exposure = 0.15;
	float decay = 0.97;
	float density = 0.97;
	float weight = 0.5;
	extern vec2 lightPos;
	int sampleMax = 80;
	
	vec4 effect(vec4 color, Image texture, vec2 tc, vec2 sc){
		vec4 txcolor = Texel(texture,tc);
		vec2 dtc = vec2((sc.x-lightPos.x)/800, (sc.y-lightPos.y)/600);
		dtc*=1.0 / float(sampleMax) * density;
		float lmnDecay = 1.0 ;
		
		for (int i = 0; i < sampleMax; i++) {
			tc.xy -= dtc.xy;
			vec4 sample = Texel(texture,tc);
			sample*= lmnDecay*weight;
			color += sample;
			lmnDecay *= decay;
		}
		color *= exposure;
		return color;
	}
]]


function love.load()
	time =  0
	lg = love.graphics
	sw = love.graphics.getWidth()
	sh = love.graphics.getHeight()
	function white() lg.setColor(1,1,1) end
	function black() lg.setColor(0,0,0) end
	bloom = lg.newShader(bloomCode)
	canv = lg.newCanvas()
	moony = -200
	t1y,t2y,t3y,t4y = 460,460,410,410
	A,B,C,Z = 0.012,0.009,0.0075,0.004
	
	batsounds = love.audio.newSource('sounds/bats2.wav', 'static')
	bells = love.audio.newSource('sounds/bells.mp3', 'static')
	wind = love.audio.newSource('sounds/wind.ogg', 'static')
	wind:setLooping(true)
	moon = lg.newImage('moon.png')
	sky = lg.newImage('sky.png')
	tree1 = lg.newImage('tree1.png')
	tree2 = lg.newImage('tree2.png')
	
	batpics = {}
	for i= 1, 11 do
		batpics[i] = lg.newImage('bat/bat' .. i .. '.png')
	end
	makeBats()
	batsOn = false
	bellsOn = false
	
	wind:play()
	
	bloom:send('a',0)
	bloom:send('b',0)
	bloom:send('c',0)
	bloom:send('z',0)
end

function love.update(dt)
	time = time+dt
	mx,my = love.mouse.getPosition()
	if batsOn then updateBats(dt) end
	updateCanv()
	
	if time%80 > 5 and time%80 < 10 then
		bloom:send('a',A*(time%80-5)/5)
		bloom:send('b',B*(time%80-5)/5)
		bloom:send('c',C*(time%80-5)/5)
		bloom:send('z',Z*(time%80-5)/5)
	end
	
	if time%80 > 5 and time%80 < 13 then
		moony = moony+(500/8)*dt
		t1y = t1y + (100/8)*dt
		t2y = t2y + (100/8)*dt
		t3y = t3y + (100/8)*dt
		t4y = t4y + (100/8)*dt
		if not bellsOn then bellsOn = true bells:play() end
	end
	
	if time%80 > 6 and time%80 < 8 and not batsOn then
		batsounds:play()
		batsOn = true
	end
	
	if time%80 > 49 and time%80 < 57 then
		moony = moony-(500/8)*dt
		t1y = t1y - (100/8)*dt
		t2y = t2y - (100/8)*dt
		t3y = t3y - (100/8)*dt
		t4y = t4y - (100/8)*dt
	end
	
	if time%80 > 49 and time%80 < 53 then
		bloom:send('a',A-A*(time%80-49)/5)
		bloom:send('b',B-B*(time%80-49)/5)
		bloom:send('c',C-C*(time%80-49)/5)
		bloom:send('z',Z-Z*(time%80-49)/5)
	end
	
	if time%80 > 50 and bellsOn and batsOn then
		bellsOn = false
		batsOn = false
		makeBats()
	end
	
end

function love.draw()
	
	white()
	lg.draw(sky)
	
	lg.setShader(bloom)
	lg.draw(canv,0,0)
	lg.setShader()
	
	black()
	lg.draw(tree1,200,t1y,0,1,1,tree1:getWidth()/2,tree1:getHeight()/2)
	lg.draw(tree1,800,t2y,0,-1.5,1.5,tree1:getWidth()/2,tree1:getHeight()/2)
	lg.draw(tree2,700,t3y,0,1,1,tree2:getWidth()/2,tree2:getHeight()/2)
	lg.draw(tree2,100,t4y,0,-1.5,1.5,tree2:getWidth()/2,tree2:getHeight()/2)
end




function updateCanv()
	lg.clear()
	lg.setCanvas(canv)
		
		lg.setColor(200/255,200/255,225/255)
		lg.draw(moon,sw/2,moony,0,1.2,1.2,moon:getWidth()/2,moon:getHeight()/2)
		black()
		drawBats()
	lg.setCanvas()
end

function makeBats()
	bats = {}
	for i =1, 30 do
		bats[i] = {
			x = -400 + math.floor(math.random()*1600),
			moveSpeed = math.random(20,50),
			flapSpeed = math.random(2,5)*10,
			dx = math.random(300,500),
			dy = math.random(-100,-200),
			frame = math.random(1,11),
			SIZE = .25 + math.random()*.25,
			size = SIZE
		}
		if bats[i].x < -200 or bats[i].x > 1000 then bats[i].y = math.random(300,600) else bats[i].y = math.random(850,1650) end
	end
end

function updateBats(dt)
	for i,bat in ipairs(bats) do
		--move bat
		local distx,disty = bat.dx - bat.x, bat.dy - bat.y
		bat.x = bat.x + (distx/100)*dt*bat.moveSpeed
		bat.y = bat.y + (disty/100)*dt*bat.moveSpeed
		local iy = 600-bat.y
		bat.size = bat.SIZE - bat.SIZE*((1.1*iy)/600)*0.9
	end
end

function drawBats()
	for i,bat in ipairs(bats) do
		lg.draw(batpics[(bat.frame+math.floor(time*bat.flapSpeed))%11+1],bat.x,bat.y,0,bat.size,bat.size,256,256)
	end
end










